@@ -5,11 +5,8 @@ import click
 from prettytable import PrettyTable
 
 from mootdx import __version__
-from mootdx.logger import logger, reset as logger_reset
-from mootdx import server
-from mootdx.affair import Affair
-from mootdx.quotes import Quotes
-from mootdx.reader import Reader
+from mootdx.logger import logger
+from mootdx.logger import reset as logger_reset
 from mootdx.utils import get_config_path
 from mootdx.utils import to_file
 
@@ -35,6 +32,7 @@ def entry():
 @click.option('-a', '--action', default='bars', help='操作类型 (daily: 日线, minute: 一分钟线, fzline: 五分钟线).', )
 @click.option('-m', '--market', default='std', help='证券市场, 默认 std (std: 标准股票市场, ext: 扩展市场).')
 def quotes(symbol, action, market, output):
+    from mootdx.quotes import Quotes
     client = Quotes.factory(market=market, multithread=True)
 
     try:
@@ -63,6 +61,7 @@ def quotes(symbol, action, market, output):
 @click.option('-m', '--market', default='std', help='证券市场, 默认 std (std: 标准股票市场, ext: 扩展市场).')
 @click.option('-o', '--output', default=None, help='输出文件, 支持 CSV, HDF5, Excel 等格式.')
 def reader(symbol, action, market, tdxdir, output):
+    from mootdx.reader import Reader
     client = Reader.factory(market=market, tdxdir=tdxdir)
 
     try:
@@ -73,14 +72,26 @@ def reader(symbol, action, market, tdxdir, output):
         raise e
 
 
-@entry.command(help='测试行情服务器.')
+@entry.command(help='添加行情服务器.', name='remote')
+@click.help_option('-h', '--help')
+@click.option('-v', '--verbose', count=True, help='详细模式')
+@click.argument('server')
+def channel(server, verbose):
+    logger_reset(verbose=verbose)
+    config = get_config_path('config.json')
+    logger.success('[√] 已经将最优服务器IP写入配置文件 {} {}'.format(config, server))
+
+
+@entry.command(help='测试行情服务器.', name='bestip')
 @click.help_option('-h', '--help')
 @click.option('-l', '--limit', default=5, help='显示最快前几个，默认 5.')
 @click.option('-v', '--verbose', count=True, help='详细模式')
-def bestip(limit, verbose):
+def server(limit, verbose):
+    from mootdx.server import bestip
+
     logger_reset(verbose=verbose)
     config = get_config_path('config.json')
-    server.bestip(limit=limit, console=True, sync=False)
+    bestip(limit=limit, console=True, sync=False)
     logger.success('[√] 已经将最优服务器IP写入配置文件 {}'.format(config))
 
 
@@ -94,6 +105,8 @@ def bestip(limit, verbose):
 @click.option('-l', '--listfile', is_flag=True, default=False, help='显示全部文件')
 @click.option('-v', '--verbose', count=True, help='详细模式')
 def affair(parse, fetch, downdir, output, downall, verbose, listfile):
+    from mootdx.affair import Affair
+
     logger_reset(verbose=verbose)
 
     files = Affair.files()
@@ -147,6 +160,8 @@ def bundle(symbol, action, market, output, extension):
     批量下载行情数据
     :return:
     """
+    from mootdx.quotes import Quotes
+
     client = Quotes.factory(market=market, multithread=True)
     symbol = symbol.replace('，', ',').strip(',').split(',')
 
