@@ -19,7 +19,6 @@ KLINE_WEEKLY = 5
 # 6 -   月K 线
 KLINE_MONTHLY = 6
 # 7 -   扩展市场 1 分钟
-
 KLINE_EX_1MIN = 7
 # 8 -   1 分钟K 线
 KLINE_1MIN = 8
@@ -32,9 +31,12 @@ KLINE_YEARLY = 11
 
 # 分笔行情最多2000条
 MAX_TRANSACTION_COUNT = 2000
+
 # K线数据最多800条
 MAX_KLINE_COUNT = 800
 
+FREQUENCY = ['5m', '15m', '30m', '1h', 'day', 'week', 'mon', 'ex_1m', '1m', 'dk', '3mon', 'year']
+
 # 板块相关参数
 BLOCK_SZ = 'block_zs.dat'
 BLOCK_FG = 'block_fg.dat'
@@ -81,3 +83,16 @@ CONFIG = {
 def return_last_value(retry_state):
     """return the result of the last call attempt"""
     return retry_state.outcome.result()
+
+# 5MIN = 0
+# 15MIN = 1
+# 30MIN = 2
+# 1HOUR = 3
+# DAILY = 4
+# WEEKLY = 5
+# MONTHLY = 6
+# EX_1MIN = 7
+# 1MIN = 8
+# RI_K = 9
+# 3MONTH = 10
+# YEARLY = 11
